@@ -37,47 +37,47 @@ else:
 __all__ = (
     "CategoricalParameterRangeTypeDef",
     "ContinuousParameterRangeTypeDef",
-    "CreateDatasetGroupRequestTypeDef",
-    "CreateDatasetGroupResponseResponseTypeDef",
-    "CreateDatasetImportJobRequestTypeDef",
-    "CreateDatasetImportJobResponseResponseTypeDef",
-    "CreateDatasetRequestTypeDef",
-    "CreateDatasetResponseResponseTypeDef",
-    "CreateForecastExportJobRequestTypeDef",
-    "CreateForecastExportJobResponseResponseTypeDef",
-    "CreateForecastRequestTypeDef",
-    "CreateForecastResponseResponseTypeDef",
-    "CreatePredictorBacktestExportJobRequestTypeDef",
-    "CreatePredictorBacktestExportJobResponseResponseTypeDef",
-    "CreatePredictorRequestTypeDef",
-    "CreatePredictorResponseResponseTypeDef",
+    "CreateDatasetGroupRequestRequestTypeDef",
+    "CreateDatasetGroupResponseTypeDef",
+    "CreateDatasetImportJobRequestRequestTypeDef",
+    "CreateDatasetImportJobResponseTypeDef",
+    "CreateDatasetRequestRequestTypeDef",
+    "CreateDatasetResponseTypeDef",
+    "CreateForecastExportJobRequestRequestTypeDef",
+    "CreateForecastExportJobResponseTypeDef",
+    "CreateForecastRequestRequestTypeDef",
+    "CreateForecastResponseTypeDef",
+    "CreatePredictorBacktestExportJobRequestRequestTypeDef",
+    "CreatePredictorBacktestExportJobResponseTypeDef",
+    "CreatePredictorRequestRequestTypeDef",
+    "CreatePredictorResponseTypeDef",
     "DataDestinationTypeDef",
     "DataSourceTypeDef",
     "DatasetGroupSummaryTypeDef",
     "DatasetImportJobSummaryTypeDef",
     "DatasetSummaryTypeDef",
-    "DeleteDatasetGroupRequestTypeDef",
-    "DeleteDatasetImportJobRequestTypeDef",
-    "DeleteDatasetRequestTypeDef",
-    "DeleteForecastExportJobRequestTypeDef",
-    "DeleteForecastRequestTypeDef",
-    "DeletePredictorBacktestExportJobRequestTypeDef",
-    "DeletePredictorRequestTypeDef",
-    "DeleteResourceTreeRequestTypeDef",
-    "DescribeDatasetGroupRequestTypeDef",
-    "DescribeDatasetGroupResponseResponseTypeDef",
-    "DescribeDatasetImportJobRequestTypeDef",
-    "DescribeDatasetImportJobResponseResponseTypeDef",
-    "DescribeDatasetRequestTypeDef",
-    "DescribeDatasetResponseResponseTypeDef",
-    "DescribeForecastExportJobRequestTypeDef",
-    "DescribeForecastExportJobResponseResponseTypeDef",
-    "DescribeForecastRequestTypeDef",
-    "DescribeForecastResponseResponseTypeDef",
-    "DescribePredictorBacktestExportJobRequestTypeDef",
-    "DescribePredictorBacktestExportJobResponseResponseTypeDef",
-    "DescribePredictorRequestTypeDef",
-    "DescribePredictorResponseResponseTypeDef",
+    "DeleteDatasetGroupRequestRequestTypeDef",
+    "DeleteDatasetImportJobRequestRequestTypeDef",
+    "DeleteDatasetRequestRequestTypeDef",
+    "DeleteForecastExportJobRequestRequestTypeDef",
+    "DeleteForecastRequestRequestTypeDef",
+    "DeletePredictorBacktestExportJobRequestRequestTypeDef",
+    "DeletePredictorRequestRequestTypeDef",
+    "DeleteResourceTreeRequestRequestTypeDef",
+    "DescribeDatasetGroupRequestRequestTypeDef",
+    "DescribeDatasetGroupResponseTypeDef",
+    "DescribeDatasetImportJobRequestRequestTypeDef",
+    "DescribeDatasetImportJobResponseTypeDef",
+    "DescribeDatasetRequestRequestTypeDef",
+    "DescribeDatasetResponseTypeDef",
+    "DescribeForecastExportJobRequestRequestTypeDef",
+    "DescribeForecastExportJobResponseTypeDef",
+    "DescribeForecastRequestRequestTypeDef",
+    "DescribeForecastResponseTypeDef",
+    "DescribePredictorBacktestExportJobRequestRequestTypeDef",
+    "DescribePredictorBacktestExportJobResponseTypeDef",
+    "DescribePredictorRequestRequestTypeDef",
+    "DescribePredictorResponseTypeDef",
     "EncryptionConfigTypeDef",
     "ErrorMetricTypeDef",
     "EvaluationParametersTypeDef",
@@ -88,27 +88,27 @@ __all__ = (
     "FilterTypeDef",
     "ForecastExportJobSummaryTypeDef",
     "ForecastSummaryTypeDef",
-    "GetAccuracyMetricsRequestTypeDef",
-    "GetAccuracyMetricsResponseResponseTypeDef",
+    "GetAccuracyMetricsRequestRequestTypeDef",
+    "GetAccuracyMetricsResponseTypeDef",
     "HyperParameterTuningJobConfigTypeDef",
     "InputDataConfigTypeDef",
     "IntegerParameterRangeTypeDef",
-    "ListDatasetGroupsRequestTypeDef",
-    "ListDatasetGroupsResponseResponseTypeDef",
-    "ListDatasetImportJobsRequestTypeDef",
-    "ListDatasetImportJobsResponseResponseTypeDef",
-    "ListDatasetsRequestTypeDef",
-    "ListDatasetsResponseResponseTypeDef",
-    "ListForecastExportJobsRequestTypeDef",
-    "ListForecastExportJobsResponseResponseTypeDef",
-    "ListForecastsRequestTypeDef",
-    "ListForecastsResponseResponseTypeDef",
-    "ListPredictorBacktestExportJobsRequestTypeDef",
-    "ListPredictorBacktestExportJobsResponseResponseTypeDef",
-    "ListPredictorsRequestTypeDef",
-    "ListPredictorsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListDatasetGroupsRequestRequestTypeDef",
+    "ListDatasetGroupsResponseTypeDef",
+    "ListDatasetImportJobsRequestRequestTypeDef",
+    "ListDatasetImportJobsResponseTypeDef",
+    "ListDatasetsRequestRequestTypeDef",
+    "ListDatasetsResponseTypeDef",
+    "ListForecastExportJobsRequestRequestTypeDef",
+    "ListForecastExportJobsResponseTypeDef",
+    "ListForecastsRequestRequestTypeDef",
+    "ListForecastsResponseTypeDef",
+    "ListPredictorBacktestExportJobsRequestRequestTypeDef",
+    "ListPredictorBacktestExportJobsResponseTypeDef",
+    "ListPredictorsRequestRequestTypeDef",
+    "ListPredictorsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MetricsTypeDef",
     "PaginatorConfigTypeDef",
     "ParameterRangesTypeDef",
@@ -121,13 +121,13 @@ __all__ = (
     "SchemaAttributeTypeDef",
     "SchemaTypeDef",
     "StatisticsTypeDef",
-    "StopResourceRequestTypeDef",
+    "StopResourceRequestRequestTypeDef",
     "SupplementaryFeatureTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TestWindowSummaryTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateDatasetGroupRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateDatasetGroupRequestRequestTypeDef",
     "WeightedQuantileLossTypeDef",
     "WindowSummaryTypeDef",
 )
@@ -163,15 +163,15 @@ class ContinuousParameterRangeTypeDef(
     pass
 
 
-_RequiredCreateDatasetGroupRequestTypeDef = TypedDict(
-    "_RequiredCreateDatasetGroupRequestTypeDef",
+_RequiredCreateDatasetGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetGroupRequestRequestTypeDef",
     {
         "DatasetGroupName": str,
         "Domain": DomainType,
     },
 )
-_OptionalCreateDatasetGroupRequestTypeDef = TypedDict(
-    "_OptionalCreateDatasetGroupRequestTypeDef",
+_OptionalCreateDatasetGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetGroupRequestRequestTypeDef",
     {
         "DatasetArns": List[str],
         "Tags": List["TagTypeDef"],
@@ -180,30 +180,31 @@ _OptionalCreateDatasetGroupRequestTypeDef = TypedDict(
 )
 
 
-class CreateDatasetGroupRequestTypeDef(
-    _RequiredCreateDatasetGroupRequestTypeDef, _OptionalCreateDatasetGroupRequestTypeDef
+class CreateDatasetGroupRequestRequestTypeDef(
+    _RequiredCreateDatasetGroupRequestRequestTypeDef,
+    _OptionalCreateDatasetGroupRequestRequestTypeDef,
 ):
     pass
 
 
-CreateDatasetGroupResponseResponseTypeDef = TypedDict(
-    "CreateDatasetGroupResponseResponseTypeDef",
+CreateDatasetGroupResponseTypeDef = TypedDict(
+    "CreateDatasetGroupResponseTypeDef",
     {
         "DatasetGroupArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateDatasetImportJobRequestTypeDef = TypedDict(
-    "_RequiredCreateDatasetImportJobRequestTypeDef",
+_RequiredCreateDatasetImportJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetImportJobRequestRequestTypeDef",
     {
         "DatasetImportJobName": str,
         "DatasetArn": str,
         "DataSource": "DataSourceTypeDef",
     },
 )
-_OptionalCreateDatasetImportJobRequestTypeDef = TypedDict(
-    "_OptionalCreateDatasetImportJobRequestTypeDef",
+_OptionalCreateDatasetImportJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetImportJobRequestRequestTypeDef",
     {
         "TimestampFormat": str,
         "TimeZone": str,
@@ -215,22 +216,23 @@ _OptionalCreateDatasetImportJobRequestTypeDef = TypedDict(
 )
 
 
-class CreateDatasetImportJobRequestTypeDef(
-    _RequiredCreateDatasetImportJobRequestTypeDef, _OptionalCreateDatasetImportJobRequestTypeDef
+class CreateDatasetImportJobRequestRequestTypeDef(
+    _RequiredCreateDatasetImportJobRequestRequestTypeDef,
+    _OptionalCreateDatasetImportJobRequestRequestTypeDef,
 ):
     pass
 
 
-CreateDatasetImportJobResponseResponseTypeDef = TypedDict(
-    "CreateDatasetImportJobResponseResponseTypeDef",
+CreateDatasetImportJobResponseTypeDef = TypedDict(
+    "CreateDatasetImportJobResponseTypeDef",
     {
         "DatasetImportJobArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateDatasetRequestTypeDef = TypedDict(
-    "_RequiredCreateDatasetRequestTypeDef",
+_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestRequestTypeDef",
     {
         "DatasetName": str,
         "Domain": DomainType,
@@ -238,8 +240,8 @@ _RequiredCreateDatasetRequestTypeDef = TypedDict(
         "Schema": "SchemaTypeDef",
     },
 )
-_OptionalCreateDatasetRequestTypeDef = TypedDict(
-    "_OptionalCreateDatasetRequestTypeDef",
+_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestRequestTypeDef",
     {
         "DataFrequency": str,
         "EncryptionConfig": "EncryptionConfigTypeDef",
@@ -249,30 +251,30 @@ _OptionalCreateDatasetRequestTypeDef = TypedDict(
 )
 
 
-class CreateDatasetRequestTypeDef(
-    _RequiredCreateDatasetRequestTypeDef, _OptionalCreateDatasetRequestTypeDef
+class CreateDatasetRequestRequestTypeDef(
+    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
 ):
     pass
 
 
-CreateDatasetResponseResponseTypeDef = TypedDict(
-    "CreateDatasetResponseResponseTypeDef",
+CreateDatasetResponseTypeDef = TypedDict(
+    "CreateDatasetResponseTypeDef",
     {
         "DatasetArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateForecastExportJobRequestTypeDef = TypedDict(
-    "_RequiredCreateForecastExportJobRequestTypeDef",
+_RequiredCreateForecastExportJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateForecastExportJobRequestRequestTypeDef",
     {
         "ForecastExportJobName": str,
         "ForecastArn": str,
         "Destination": "DataDestinationTypeDef",
     },
 )
-_OptionalCreateForecastExportJobRequestTypeDef = TypedDict(
-    "_OptionalCreateForecastExportJobRequestTypeDef",
+_OptionalCreateForecastExportJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateForecastExportJobRequestRequestTypeDef",
     {
         "Tags": List["TagTypeDef"],
     },
@@ -280,29 +282,30 @@ _OptionalCreateForecastExportJobRequestTypeDef = TypedDict(
 )
 
 
-class CreateForecastExportJobRequestTypeDef(
-    _RequiredCreateForecastExportJobRequestTypeDef, _OptionalCreateForecastExportJobRequestTypeDef
+class CreateForecastExportJobRequestRequestTypeDef(
+    _RequiredCreateForecastExportJobRequestRequestTypeDef,
+    _OptionalCreateForecastExportJobRequestRequestTypeDef,
 ):
     pass
 
 
-CreateForecastExportJobResponseResponseTypeDef = TypedDict(
-    "CreateForecastExportJobResponseResponseTypeDef",
+CreateForecastExportJobResponseTypeDef = TypedDict(
+    "CreateForecastExportJobResponseTypeDef",
     {
         "ForecastExportJobArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateForecastRequestTypeDef = TypedDict(
-    "_RequiredCreateForecastRequestTypeDef",
+_RequiredCreateForecastRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateForecastRequestRequestTypeDef",
     {
         "ForecastName": str,
         "PredictorArn": str,
     },
 )
-_OptionalCreateForecastRequestTypeDef = TypedDict(
-    "_OptionalCreateForecastRequestTypeDef",
+_OptionalCreateForecastRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateForecastRequestRequestTypeDef",
     {
         "ForecastTypes": List[str],
         "Tags": List["TagTypeDef"],
@@ -311,30 +314,30 @@ _OptionalCreateForecastRequestTypeDef = TypedDict(
 )
 
 
-class CreateForecastRequestTypeDef(
-    _RequiredCreateForecastRequestTypeDef, _OptionalCreateForecastRequestTypeDef
+class CreateForecastRequestRequestTypeDef(
+    _RequiredCreateForecastRequestRequestTypeDef, _OptionalCreateForecastRequestRequestTypeDef
 ):
     pass
 
 
-CreateForecastResponseResponseTypeDef = TypedDict(
-    "CreateForecastResponseResponseTypeDef",
+CreateForecastResponseTypeDef = TypedDict(
+    "CreateForecastResponseTypeDef",
     {
         "ForecastArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreatePredictorBacktestExportJobRequestTypeDef = TypedDict(
-    "_RequiredCreatePredictorBacktestExportJobRequestTypeDef",
+_RequiredCreatePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePredictorBacktestExportJobRequestRequestTypeDef",
     {
         "PredictorBacktestExportJobName": str,
         "PredictorArn": str,
         "Destination": "DataDestinationTypeDef",
     },
 )
-_OptionalCreatePredictorBacktestExportJobRequestTypeDef = TypedDict(
-    "_OptionalCreatePredictorBacktestExportJobRequestTypeDef",
+_OptionalCreatePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePredictorBacktestExportJobRequestRequestTypeDef",
     {
         "Tags": List["TagTypeDef"],
     },
@@ -342,23 +345,23 @@ _OptionalCreatePredictorBacktestExportJobRequestTypeDef = TypedDict(
 )
 
 
-class CreatePredictorBacktestExportJobRequestTypeDef(
-    _RequiredCreatePredictorBacktestExportJobRequestTypeDef,
-    _OptionalCreatePredictorBacktestExportJobRequestTypeDef,
+class CreatePredictorBacktestExportJobRequestRequestTypeDef(
+    _RequiredCreatePredictorBacktestExportJobRequestRequestTypeDef,
+    _OptionalCreatePredictorBacktestExportJobRequestRequestTypeDef,
 ):
     pass
 
 
-CreatePredictorBacktestExportJobResponseResponseTypeDef = TypedDict(
-    "CreatePredictorBacktestExportJobResponseResponseTypeDef",
+CreatePredictorBacktestExportJobResponseTypeDef = TypedDict(
+    "CreatePredictorBacktestExportJobResponseTypeDef",
     {
         "PredictorBacktestExportJobArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreatePredictorRequestTypeDef = TypedDict(
-    "_RequiredCreatePredictorRequestTypeDef",
+_RequiredCreatePredictorRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePredictorRequestRequestTypeDef",
     {
         "PredictorName": str,
         "ForecastHorizon": int,
@@ -366,8 +369,8 @@ _RequiredCreatePredictorRequestTypeDef = TypedDict(
         "FeaturizationConfig": "FeaturizationConfigTypeDef",
     },
 )
-_OptionalCreatePredictorRequestTypeDef = TypedDict(
-    "_OptionalCreatePredictorRequestTypeDef",
+_OptionalCreatePredictorRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePredictorRequestRequestTypeDef",
     {
         "AlgorithmArn": str,
         "ForecastTypes": List[str],
@@ -384,14 +387,14 @@ _OptionalCreatePredictorRequestTypeDef = TypedDict(
 )
 
 
-class CreatePredictorRequestTypeDef(
-    _RequiredCreatePredictorRequestTypeDef, _OptionalCreatePredictorRequestTypeDef
+class CreatePredictorRequestRequestTypeDef(
+    _RequiredCreatePredictorRequestRequestTypeDef, _OptionalCreatePredictorRequestRequestTypeDef
 ):
     pass
 
 
-CreatePredictorResponseResponseTypeDef = TypedDict(
-    "CreatePredictorResponseResponseTypeDef",
+CreatePredictorResponseTypeDef = TypedDict(
+    "CreatePredictorResponseTypeDef",
     {
         "PredictorArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -450,71 +453,71 @@ DatasetSummaryTypeDef = TypedDict(
     total=False,
 )
 
-DeleteDatasetGroupRequestTypeDef = TypedDict(
-    "DeleteDatasetGroupRequestTypeDef",
+DeleteDatasetGroupRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetGroupRequestRequestTypeDef",
     {
         "DatasetGroupArn": str,
     },
 )
 
-DeleteDatasetImportJobRequestTypeDef = TypedDict(
-    "DeleteDatasetImportJobRequestTypeDef",
+DeleteDatasetImportJobRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetImportJobRequestRequestTypeDef",
     {
         "DatasetImportJobArn": str,
     },
 )
 
-DeleteDatasetRequestTypeDef = TypedDict(
-    "DeleteDatasetRequestTypeDef",
+DeleteDatasetRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestRequestTypeDef",
     {
         "DatasetArn": str,
     },
 )
 
-DeleteForecastExportJobRequestTypeDef = TypedDict(
-    "DeleteForecastExportJobRequestTypeDef",
+DeleteForecastExportJobRequestRequestTypeDef = TypedDict(
+    "DeleteForecastExportJobRequestRequestTypeDef",
     {
         "ForecastExportJobArn": str,
     },
 )
 
-DeleteForecastRequestTypeDef = TypedDict(
-    "DeleteForecastRequestTypeDef",
+DeleteForecastRequestRequestTypeDef = TypedDict(
+    "DeleteForecastRequestRequestTypeDef",
     {
         "ForecastArn": str,
     },
 )
 
-DeletePredictorBacktestExportJobRequestTypeDef = TypedDict(
-    "DeletePredictorBacktestExportJobRequestTypeDef",
+DeletePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
+    "DeletePredictorBacktestExportJobRequestRequestTypeDef",
     {
         "PredictorBacktestExportJobArn": str,
     },
 )
 
-DeletePredictorRequestTypeDef = TypedDict(
-    "DeletePredictorRequestTypeDef",
+DeletePredictorRequestRequestTypeDef = TypedDict(
+    "DeletePredictorRequestRequestTypeDef",
     {
         "PredictorArn": str,
     },
 )
 
-DeleteResourceTreeRequestTypeDef = TypedDict(
-    "DeleteResourceTreeRequestTypeDef",
+DeleteResourceTreeRequestRequestTypeDef = TypedDict(
+    "DeleteResourceTreeRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
 
-DescribeDatasetGroupRequestTypeDef = TypedDict(
-    "DescribeDatasetGroupRequestTypeDef",
+DescribeDatasetGroupRequestRequestTypeDef = TypedDict(
+    "DescribeDatasetGroupRequestRequestTypeDef",
     {
         "DatasetGroupArn": str,
     },
 )
 
-DescribeDatasetGroupResponseResponseTypeDef = TypedDict(
-    "DescribeDatasetGroupResponseResponseTypeDef",
+DescribeDatasetGroupResponseTypeDef = TypedDict(
+    "DescribeDatasetGroupResponseTypeDef",
     {
         "DatasetGroupName": str,
         "DatasetGroupArn": str,
@@ -527,15 +530,15 @@ DescribeDatasetGroupResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeDatasetImportJobRequestTypeDef = TypedDict(
-    "DescribeDatasetImportJobRequestTypeDef",
+DescribeDatasetImportJobRequestRequestTypeDef = TypedDict(
+    "DescribeDatasetImportJobRequestRequestTypeDef",
     {
         "DatasetImportJobArn": str,
     },
 )
 
-DescribeDatasetImportJobResponseResponseTypeDef = TypedDict(
-    "DescribeDatasetImportJobResponseResponseTypeDef",
+DescribeDatasetImportJobResponseTypeDef = TypedDict(
+    "DescribeDatasetImportJobResponseTypeDef",
     {
         "DatasetImportJobName": str,
         "DatasetImportJobArn": str,
@@ -556,15 +559,15 @@ DescribeDatasetImportJobResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeDatasetRequestTypeDef = TypedDict(
-    "DescribeDatasetRequestTypeDef",
+DescribeDatasetRequestRequestTypeDef = TypedDict(
+    "DescribeDatasetRequestRequestTypeDef",
     {
         "DatasetArn": str,
     },
 )
 
-DescribeDatasetResponseResponseTypeDef = TypedDict(
-    "DescribeDatasetResponseResponseTypeDef",
+DescribeDatasetResponseTypeDef = TypedDict(
+    "DescribeDatasetResponseTypeDef",
     {
         "DatasetArn": str,
         "DatasetName": str,
@@ -580,15 +583,15 @@ DescribeDatasetResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeForecastExportJobRequestTypeDef = TypedDict(
-    "DescribeForecastExportJobRequestTypeDef",
+DescribeForecastExportJobRequestRequestTypeDef = TypedDict(
+    "DescribeForecastExportJobRequestRequestTypeDef",
     {
         "ForecastExportJobArn": str,
     },
 )
 
-DescribeForecastExportJobResponseResponseTypeDef = TypedDict(
-    "DescribeForecastExportJobResponseResponseTypeDef",
+DescribeForecastExportJobResponseTypeDef = TypedDict(
+    "DescribeForecastExportJobResponseTypeDef",
     {
         "ForecastExportJobArn": str,
         "ForecastExportJobName": str,
@@ -602,15 +605,15 @@ DescribeForecastExportJobResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeForecastRequestTypeDef = TypedDict(
-    "DescribeForecastRequestTypeDef",
+DescribeForecastRequestRequestTypeDef = TypedDict(
+    "DescribeForecastRequestRequestTypeDef",
     {
         "ForecastArn": str,
     },
 )
 
-DescribeForecastResponseResponseTypeDef = TypedDict(
-    "DescribeForecastResponseResponseTypeDef",
+DescribeForecastResponseTypeDef = TypedDict(
+    "DescribeForecastResponseTypeDef",
     {
         "ForecastArn": str,
         "ForecastName": str,
@@ -626,15 +629,15 @@ DescribeForecastResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribePredictorBacktestExportJobRequestTypeDef = TypedDict(
-    "DescribePredictorBacktestExportJobRequestTypeDef",
+DescribePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
+    "DescribePredictorBacktestExportJobRequestRequestTypeDef",
     {
         "PredictorBacktestExportJobArn": str,
     },
 )
 
-DescribePredictorBacktestExportJobResponseResponseTypeDef = TypedDict(
-    "DescribePredictorBacktestExportJobResponseResponseTypeDef",
+DescribePredictorBacktestExportJobResponseTypeDef = TypedDict(
+    "DescribePredictorBacktestExportJobResponseTypeDef",
     {
         "PredictorBacktestExportJobArn": str,
         "PredictorBacktestExportJobName": str,
@@ -648,15 +651,15 @@ DescribePredictorBacktestExportJobResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribePredictorRequestTypeDef = TypedDict(
-    "DescribePredictorRequestTypeDef",
+DescribePredictorRequestRequestTypeDef = TypedDict(
+    "DescribePredictorRequestRequestTypeDef",
     {
         "PredictorArn": str,
     },
 )
 
-DescribePredictorResponseResponseTypeDef = TypedDict(
-    "DescribePredictorResponseResponseTypeDef",
+DescribePredictorResponseTypeDef = TypedDict(
+    "DescribePredictorResponseTypeDef",
     {
         "PredictorArn": str,
         "PredictorName": str,
@@ -820,15 +823,15 @@ ForecastSummaryTypeDef = TypedDict(
     total=False,
 )
 
-GetAccuracyMetricsRequestTypeDef = TypedDict(
-    "GetAccuracyMetricsRequestTypeDef",
+GetAccuracyMetricsRequestRequestTypeDef = TypedDict(
+    "GetAccuracyMetricsRequestRequestTypeDef",
     {
         "PredictorArn": str,
     },
 )
 
-GetAccuracyMetricsResponseResponseTypeDef = TypedDict(
-    "GetAccuracyMetricsResponseResponseTypeDef",
+GetAccuracyMetricsResponseTypeDef = TypedDict(
+    "GetAccuracyMetricsResponseTypeDef",
     {
         "PredictorEvaluationResults": List["EvaluationResultTypeDef"],
         "AutoMLOverrideStrategy": Literal["LatencyOptimized"],
@@ -886,8 +889,8 @@ class IntegerParameterRangeTypeDef(
     pass
 
 
-ListDatasetGroupsRequestTypeDef = TypedDict(
-    "ListDatasetGroupsRequestTypeDef",
+ListDatasetGroupsRequestRequestTypeDef = TypedDict(
+    "ListDatasetGroupsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -895,8 +898,8 @@ ListDatasetGroupsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDatasetGroupsResponseResponseTypeDef = TypedDict(
-    "ListDatasetGroupsResponseResponseTypeDef",
+ListDatasetGroupsResponseTypeDef = TypedDict(
+    "ListDatasetGroupsResponseTypeDef",
     {
         "DatasetGroups": List["DatasetGroupSummaryTypeDef"],
         "NextToken": str,
@@ -904,8 +907,8 @@ ListDatasetGroupsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListDatasetImportJobsRequestTypeDef = TypedDict(
-    "ListDatasetImportJobsRequestTypeDef",
+ListDatasetImportJobsRequestRequestTypeDef = TypedDict(
+    "ListDatasetImportJobsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -914,8 +917,8 @@ ListDatasetImportJobsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDatasetImportJobsResponseResponseTypeDef = TypedDict(
-    "ListDatasetImportJobsResponseResponseTypeDef",
+ListDatasetImportJobsResponseTypeDef = TypedDict(
+    "ListDatasetImportJobsResponseTypeDef",
     {
         "DatasetImportJobs": List["DatasetImportJobSummaryTypeDef"],
         "NextToken": str,
@@ -923,8 +926,8 @@ ListDatasetImportJobsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListDatasetsRequestTypeDef = TypedDict(
-    "ListDatasetsRequestTypeDef",
+ListDatasetsRequestRequestTypeDef = TypedDict(
+    "ListDatasetsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -932,8 +935,8 @@ ListDatasetsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDatasetsResponseResponseTypeDef = TypedDict(
-    "ListDatasetsResponseResponseTypeDef",
+ListDatasetsResponseTypeDef = TypedDict(
+    "ListDatasetsResponseTypeDef",
     {
         "Datasets": List["DatasetSummaryTypeDef"],
         "NextToken": str,
@@ -941,8 +944,8 @@ ListDatasetsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListForecastExportJobsRequestTypeDef = TypedDict(
-    "ListForecastExportJobsRequestTypeDef",
+ListForecastExportJobsRequestRequestTypeDef = TypedDict(
+    "ListForecastExportJobsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -951,8 +954,8 @@ ListForecastExportJobsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListForecastExportJobsResponseResponseTypeDef = TypedDict(
-    "ListForecastExportJobsResponseResponseTypeDef",
+ListForecastExportJobsResponseTypeDef = TypedDict(
+    "ListForecastExportJobsResponseTypeDef",
     {
         "ForecastExportJobs": List["ForecastExportJobSummaryTypeDef"],
         "NextToken": str,
@@ -960,8 +963,8 @@ ListForecastExportJobsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListForecastsRequestTypeDef = TypedDict(
-    "ListForecastsRequestTypeDef",
+ListForecastsRequestRequestTypeDef = TypedDict(
+    "ListForecastsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -970,8 +973,8 @@ ListForecastsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListForecastsResponseResponseTypeDef = TypedDict(
-    "ListForecastsResponseResponseTypeDef",
+ListForecastsResponseTypeDef = TypedDict(
+    "ListForecastsResponseTypeDef",
     {
         "Forecasts": List["ForecastSummaryTypeDef"],
         "NextToken": str,
@@ -979,8 +982,8 @@ ListForecastsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPredictorBacktestExportJobsRequestTypeDef = TypedDict(
-    "ListPredictorBacktestExportJobsRequestTypeDef",
+ListPredictorBacktestExportJobsRequestRequestTypeDef = TypedDict(
+    "ListPredictorBacktestExportJobsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -989,8 +992,8 @@ ListPredictorBacktestExportJobsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPredictorBacktestExportJobsResponseResponseTypeDef = TypedDict(
-    "ListPredictorBacktestExportJobsResponseResponseTypeDef",
+ListPredictorBacktestExportJobsResponseTypeDef = TypedDict(
+    "ListPredictorBacktestExportJobsResponseTypeDef",
     {
         "PredictorBacktestExportJobs": List["PredictorBacktestExportJobSummaryTypeDef"],
         "NextToken": str,
@@ -998,8 +1001,8 @@ ListPredictorBacktestExportJobsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPredictorsRequestTypeDef = TypedDict(
-    "ListPredictorsRequestTypeDef",
+ListPredictorsRequestRequestTypeDef = TypedDict(
+    "ListPredictorsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -1008,8 +1011,8 @@ ListPredictorsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPredictorsResponseResponseTypeDef = TypedDict(
-    "ListPredictorsResponseResponseTypeDef",
+ListPredictorsResponseTypeDef = TypedDict(
+    "ListPredictorsResponseTypeDef",
     {
         "Predictors": List["PredictorSummaryTypeDef"],
         "NextToken": str,
@@ -1017,15 +1020,15 @@ ListPredictorsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1174,8 +1177,8 @@ StatisticsTypeDef = TypedDict(
     total=False,
 )
 
-StopResourceRequestTypeDef = TypedDict(
-    "StopResourceRequestTypeDef",
+StopResourceRequestRequestTypeDef = TypedDict(
+    "StopResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
@@ -1189,8 +1192,8 @@ SupplementaryFeatureTypeDef = TypedDict(
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "Tags": List["TagTypeDef"],
@@ -1216,16 +1219,16 @@ TestWindowSummaryTypeDef = TypedDict(
     total=False,
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateDatasetGroupRequestTypeDef = TypedDict(
-    "UpdateDatasetGroupRequestTypeDef",
+UpdateDatasetGroupRequestRequestTypeDef = TypedDict(
+    "UpdateDatasetGroupRequestRequestTypeDef",
     {
         "DatasetGroupArn": str,
         "DatasetArns": List[str],
